Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2012-08-12 01:35:24 +0400
committerCampbell Barton <ideasman42@gmail.com>2012-08-12 01:35:24 +0400
commitc567cf3fab5b962a4166ef44f45c80941021b60d (patch)
treef3b257cdd6ec3c6241395ca2bb815cc82a428506 /source/blender/windowmanager/intern/wm_init_exit.c
parentf2d06dc257ec9c4667fd9964243b032fed2d21c3 (diff)
code cleanup: WM naming conventions
Diffstat (limited to 'source/blender/windowmanager/intern/wm_init_exit.c')
-rw-r--r--source/blender/windowmanager/intern/wm_init_exit.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/windowmanager/intern/wm_init_exit.c b/source/blender/windowmanager/intern/wm_init_exit.c
index 8ea644d6e5c..ac9b44fddb0 100644
--- a/source/blender/windowmanager/intern/wm_init_exit.c
+++ b/source/blender/windowmanager/intern/wm_init_exit.c
@@ -152,7 +152,7 @@ void WM_init(bContext *C, int argc, const char **argv)
BLI_init_srgb_conversion();
/* get the default database, plus a wm */
- WM_read_homefile(C, NULL, G.factory_startup);
+ WM_homefile_read(C, NULL, G.factory_startup);
BLF_lang_set(NULL);
@@ -161,7 +161,7 @@ void WM_init(bContext *C, int argc, const char **argv)
* initializing space types and other internal data.
*
* However cant redo this at the moment. Solution is to load python
* before WM_read_homefile() or make py-drivers check if python is running.
* Will try fix when the crash can be repeated. - campbell. */
#ifdef WITH_PYTHON
@@ -161,7 +161,7 @@ void WM_init(bContext *C, int argc, const char **argv)
*
* However cant redo this at the moment. Solution is to load python
- * before WM_read_homefile() or make py-drivers check if python is running.
+ * before WM_homefile_read() or make py-drivers check if python is running.
* Will try fix when the crash can be repeated. - campbell. */
#ifdef WITH_PYTHON